pub struct UserExerciseSlideSubmissionWithGrading {
pub id: Uuid,
pub exercise_id: Uuid,
pub created_at: DateTime<Utc>,
pub score_given: Option<f32>,
pub grading_progress: Option<GradingProgress>,
}Expand description
One of the user’s submissions to an exercise, with the grading of its task submission.
The exercise-services client API only serves single-task (editor) slides, so “the slide’s
grading” is unambiguous; DISTINCT ON keeps that true for any slide that has more.
Fields
id: Uuidexercise_id: Uuidcreated_at: DateTime<Utc>score_given: Option<f32>grading_progress: Option<GradingProgress>Trait Implementations
Sourceimpl Clone for UserExerciseSlideSubmissionWithGrading
impl Clone for UserExerciseSlideSubmissionWithGrading
Sourcefn clone(&self) -> UserExerciseSlideSubmissionWithGrading
fn clone(&self) -> UserExerciseSlideSubmissionWithGrading
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for UserExerciseSlideSubmissionWithGrading
impl PartialEq for UserExerciseSlideSubmissionWithGrading
Sourcefn eq(&self, other: &UserExerciseSlideSubmissionWithGrading) -> bool
fn eq(&self, other: &UserExerciseSlideSubmissionWithGrading) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UserExerciseSlideSubmissionWithGrading